@@ -14,9 +14,21 @@ class HTTPResponse:
         self._buffer_pointer = 0
 
     def __getitem__(self, key):
+        # Make sure we don't expose the Content-Encoding header
+        # Since the decoding will be handled by requests
+        if key.lower() == "content-encoding":
+            return None
+        if key.lower() == "content-length":
+            return str(len(self._body_buffer))
         return self._response.headers.get(key)
 
     def get(self, key, default=None):
+        # Make sure we don't expose the Content-Encoding header
+        # Since the decoding will be handled by requests
+        if key.lower() == "content-encoding":
+            return None
+        if key.lower() == "content-length":
+            return str(len(self._body_buffer))
         return self._response.headers.get(key) or default
 
     def read(self, length=None):
